<?php
/**
 *   @copyright Copyright (c) 2011 Quality Unit s.r.o.
 *   @author Juraj Simon
 *   @package PostAffiliatePro
 *
 *   Licensed under the Quality Unit, s.r.o. Standard End User License Agreement,
 *   Version 1.0 (the "License"); you may not use this file except in compliance
 *   with the License. You may obtain a copy of the License at
 *   http://www.postaffiliatepro.com/licenses/license
 */

/**
 * Configuration class for plugin
 * 
 * Name of this class should be always yourUniquePluginName_Config and extends from Gpf_Plugins_Config 
 */
class UserHooksExample_Config extends Gpf_Plugins_Config {
    /**
     * usually we declare some constants here, which willbe used in plugin context, for settings name or so... 
     */    
    const NOTIFICATIONS_ENABLED = 'UserHooksExampleNotificationsEnabled';
    
    /**
     * in this method you can create your own settings dialog for your plugin
     * 
     * examples of use:
     * add checkbox 
     * $this->addCheckBox($this->_("field caption in dialog"), 'constant_name', $this->_("field description - after clicking on small question mark"));
     * 
     * add password field
     * $this->addPasswordTextBox($this->_("field caption in dialog"), 'constant_name', $this->_("field description - after clicking on small question mark"));
     * 
     * add text box
     * $this->addTextBox($this->_("field caption in dialog"), 'constant_name', $this->_("field description - after clicking on small question mark"));
     * 
     * add text box with default value
     * $this->addTextBoxWithDefault($this->_('caption'), 'constant_name', 'default_value', 'default_text', $this->_("field description - after clicking on small question mark"), true/false - if default value should be set by default"));
     * 
     * add list box
     * $this->addListBox($this->_("caption"), 'constant_name', array('value'=>'Name 1','value2'=>'Name2'), $this->_('field description - after clicking on small question mark'));
     * 
     * after doing this, do not forget to check Definition and Main class also, where you must define initial database values for all these settings you just created
     */
    protected function initFields() {
        //lets create one setting which will enable or disable notifications
        $this->addCheckBox($this->_("Enable notifications"), self::NOTIFICATIONS_ENABLED, $this->_("Enable notification on various user hooks"));
    }
    
    /**
     * @service plugin_config write
     * @param Gpf_Rpc_Params $params
     * @return Gpf_Rpc_Form
     */
    public function save(Gpf_Rpc_Params $params) {
        // do not forget to add your settings also here in save method!
        $form = new Gpf_Rpc_Form($params);
        
        //settings fields
        Gpf_Settings::set(self::NOTIFICATIONS_ENABLED, $form->getFieldValue(self::NOTIFICATIONS_ENABLED));
        
        //successful save message
        $form->setInfoMessage($this->_('Settings saved'));
        return $form;
    }

    /**
     * @service plugin_config read
     * @param Gpf_Rpc_Params $params
     * @return Gpf_Rpc_Form
     */
    public function load(Gpf_Rpc_Params $params) {
        // do not forget to add your settings also here in load method!
        $form = new Gpf_Rpc_Form($params);
        
        //settings fields
        $form->addField(self::NOTIFICATIONS_ENABLED, Gpf_Settings::get(self::NOTIFICATIONS_ENABLED));
        
        return $form;
    }
}

?>