<?php
/**
 *   @copyright Copyright (c) 2011 Quality Unit s.r.o.
 *   @author Juraj Simon
 *   @package PostAffiliatePro
 *
 *   Licensed under the Quality Unit, s.r.o. Standard End User License Agreement,
 *   Version 1.0 (the "License"); you may not use this file except in compliance
 *   with the License. You may obtain a copy of the License at
 *   http://www.postaffiliatepro.com/licenses/license
 */

/**
 * Definition class for a plugin 
 * name must be like yourUniquePluginName_Definition and it must be inherited from  Gpf_Plugins_Definition
 */
class UserHooksExample_Definition extends Gpf_Plugins_Definition  {
    public function __construct() {
        //unique plugin code - must be differen from all existing plugin codes in application
        $this->codeName = 'UserHooksExample';
        //real plugin name which will show in plugins list in application
        $this->name = $this->_('User hooks example plugin');
        //plugin description - also visible in plugins list
        $this->description = $this->_('This plugin handles various Post Affiliate Pro hooks.');
        //plugin version - use format X.Y.Z
        $this->version = '1.0.0';
        // name of configuration class - this must be name of config class, you created for this plugin
        // note: if your plugin does not have configuration settings, you can delete this row and also UserHooksExample_Config class
        $this->configurationClassName = 'UserHooksExample_Config';
        
        // minimum Post Affiliate Version wihich is requred to runn this plugin
        $this->addRequirement('PapCore', '4.5.54.2');
        
        /**
         * application hooks that will be used in this plugin
         * hook has this syntax:
         * $this->addImplementation('hook_code', 'plugin_main_class', 'method_name');
         * plugin_main_class - must be your plugin Main class name, for example UserHooksExample_Main
         * method_name - must be PUBLIC method in your plugin Main class
         */         
        
        //system hook - this is requred (if your plugin have settings) - do not remove it
        $this->addImplementation('Core.defineSettings', 'UserHooksExample_Main', 'initSettings');
        //here we can see all usable hooks needed for notification about user creating/updating/deleting
        //runs its self after user successfully signs up        
        $this->addImplementation('PostAffiliate.signup.after', 'UserHooksExample_Main', 'doAfterSignup');
        //runs its self after user sign up fails for some reason
        $this->addImplementation('PostAffiliate.signup.afterFail', 'UserHooksExample_Main', 'doAfterSignupFails');
        //runs its self before user is saved to database (at this point you can also prevent save)
        $this->addImplementation('PostAffiliate.User.beforeSave', 'UserHooksExample_Main', 'doBeforeUserSave');
        //runs its self after user is saved to database (user update its profile)
        $this->addImplementation('PostAffiliate.User.afterSave', 'UserHooksExample_Main', 'doAfterUserSave');
        $this->addImplementation('Gpf_Auth_UserForm.save', 'UserHooksExample_Main', 'doAfterAuthUserSave');
        //runs its self after user is deletet from Post Affiliate Pro  
        $this->addImplementation('PostAffiliate.User.afterDelete', 'UserHooksExample_Main', 'doAfterUserDelete');
        //runs its self after user is saved to database (new record is inserted)
        $this->addImplementation('PostAffiliate.User.afterInsert', 'UserHooksExample_Main', 'doAfterUserInsert');        
    }
}
?>