<?php
/**
 *   @copyright Copyright (c) 2011 Quality Unit s.r.o.
 *   @author Juraj Simon
 *   @package PostAffiliatePro
 *
 *   Licensed under the Quality Unit, s.r.o. Standard End User License Agreement,
 *   Version 1.0 (the "License"); you may not use this file except in compliance
 *   with the License. You may obtain a copy of the License at
 *   http://www.postaffiliatepro.com/licenses/license
 */

/**
 * Plugin Main class
 * This is main class for plugin. All programmatic logic should go here.
 * class should have name like yourPluginName_Main and be inherited from Gpf_Plugins_Handler
 * You can include your classes into this file to use your code
 * In that case, be carefull with include paths... best solution is to copy your classes to plugin folder also, or creade some subdirectory    
 */
class UserHooksExample_Main extends Gpf_Plugins_Handler {
    //in this case we want singleton, but you can return new instance for every call and do not use getHandlerInstance method
    private static $instance = false;    

    //constructor can be empty if we do not want some initialization code
    public function __construct() {
        //we initialize database logger event though logging is disabled
        //Gpf_Log::addLogger(new Gpf_Log_LoggerDatabase(), Gpf_Log::DEBUG);
    }
    
    /**
     * @return UserHooksExample_Main
     */
    public static function getHandlerInstance() {
        if(!self::$instance)  {
            return self::$instance = new UserHooksExample_Main();
        }
        return self::$instance;
    }
    
    /**
     * initialize default database settings values for plugin - do not use this method, only if your plugin has no settings/configuration
     */
    public function initSettings(Gpf_Settings_Gpf $context) {
        //usage: $context->addDbSetting('setting_name', 'default_value');
        $context->addDbSetting(UserHooksExample_Config::NOTIFICATIONS_ENABLED, Gpf::YES);
    }
    
    /**
     * do after successful signup
     */
    public function doAfterSignup(Pap_Contexts_Signup $context) {
        //if notifications are disabled do nothing
        if (!$this->notificationEnabled()) {            
            return;
        }
        
        //just make an info log
        Gpf_Log::info('User ' . $context->getUserObject()->getEmail() . 'just signed up');
        
        //what info can you get from context?
        //you can get created user object by $usr = $context->getUserObject()
        //$usr will be Pap_Common_User instance
        //you can call various public method on this class - just see the code
        //examples:          $context->getUserObject()->getEmail() - user email
        //$context->getUserObject()->getStatus() - user status
        //$context->getUserObject()->getUserName() - username
        //$context->getUserObject()->getFirstName() - user first name
        //$context->getUserObject()->getLastName() - user last name
        //etc ... (more in Pap_Common_User class)
    }

    /**
     * do when user signup fails
     */
    public function doAfterSignupFails(Pap_Contexts_Signup $context) {
        if (!$this->notificationEnabled()) {
            return;
        }
        
        Gpf_Log::error('User ' . $context->getFormObject()->getFieldValue('username') . ' signup failed!');
        //what info can you get from context?
        //by caling $context->getFormObject()->getFieldValue('field_name') you can get all fields user filled in during signup
        //possible values of field_name:
        /* parentuserid
         * refid
         * data1 
         * data2 
         * data3 - data9 
         * username 
         * firstname 
         * lastname
         * agreeWithTerms
         * possible some others... depends on your configuration 
         */
    }

    /**
     * do before user is saved
     */
    public function doBeforeUserSave(Pap_Common_User $user) {        
        if (!$this->notificationEnabled()) {
            return;
        }
        // in this method you can run some checks with user data
        // if you throw exception in this method, saving will be interrupted. example:
        // throw new Gpf_Exception('User save is not allowed!!');        
        Gpf_Log::info('User ' . $user->getEmail() . ' before save check...');
        // for $user description see doAfterSignup method
    }

    /**
     * do after user is saved - merchant update his profile or affiliate update its own profile 
     */
    public function doAfterUserSave(Pap_Common_User $user) {
        if (!$this->notificationEnabled()) {
            return;
        }
        Gpf_Log::info('Users profile was updated:' . $user->getEmail());
        // for $user description see doAfterSignup method
    }
    
    public function doAfterAuthUserSave(Gpf_Db_AuthUser $authUser) {
        try {
            $affiliateUser = Pap_Affiliates_User::loadFromUsername($authUser->getUsername());
        } catch (Gpf_Exception $e) {
            return;
        }
        $this->doAfterUserSave($affiliateUser);
    }

    /**
     * do after user was deleted from pap
     */
    public function doAfterUserDelete(Pap_Common_User $user) {
        if (!$this->notificationEnabled()) {
            return;
        }
        Gpf_Log::info('User ' . $user->getEmail() . ' was deleted!');
        // for $user description see doAfterSignup method
    }
    
    /**
     * do when new user record was inserted into database (not an update of existing account)
     */
    public function doAfterUserInsert(Pap_Common_User $user) {
        if (!$this->notificationEnabled()) {
            return;
        }
        Gpf_Log::info('New user ' . $user->getEmail() . ' was successfully inserted');
        // for $user description see doAfterSignup method
    }
    
    private function notificationEnabled() {
        //if setting is checkbox type it can have two values Y or N, these two values are represented by two constants Gpf::YES and Gpf::NO
        return Gpf_Settings::get(UserHooksExample_Config::NOTIFICATIONS_ENABLED) == Gpf::YES;
    }
}
?>